# live_exam_os

This project aims to create a minimal live operating system in the form of an ISO image, specifically designed for use on any computer. The generated ISO boots directly into a lightweight XFCE desktop environment and automatically launches the nexus-client. The focus is on simplicity, speed and portability.

The ISO is based on Alpine Linux, known for its small footprint and security. LUKS encryption to secure the filesystem is enabled by default and can be disabled.

## Features

 - Minimal ISO: Starts with a lightweight Alpine Linux base.
 - Encryption: Utilizes LUKS encryption for securing the filesystem (optional).
 - Desktop Environment: Configured for autologin with a minimal desktop environment.
 - Nexus Client: Auto-launches the nexus-client at startup.
 - Customizable: Flexible options for user credentials, Alpine version, and additional files.

## Prerequisites

 - Docker: Used to containerize the build process.
 - QEMU: Optional, for testing the generated ISO.

## Environment Setup

The build.sh script use several environment variables for flexibility:

| Variable	| Description	|Example|
|-|-|-|
| SQUASHFS	| Path to SquashFS file	| out/squash.rootfs |
| ROOTFS_DIR |	Temporary root filesystem directory |	out/rootfs |
| INITRD_DIR |	Temporary initrd directory	| out/initrd |
| ISO_DIR|	Temporary ISO directory	| out/iso |
| SERVER |	Server details | 127.0.0.1:1077 |
| CERT|	Path to Certificate file	|ca-cert.pem |
| EXAM_USER|	Default user for exam client|	user |
| EXAM_PWD|	Default password for exam client |	password |

## build.sh Script

The script build.sh generates the live ISO with various options for customization.

### Syntax

./build.sh iso_output_path luks_passphrase [options]

### Required Arguments

 - iso_output_path: Path to save the generated ISO image (e.g., out/iso/alpine.iso).
 - luks_passphrase: Passphrase for LUKS encryption. Leave blank when using --no-luks.

### Options

 - --no-luks: Disable LUKS encryption (makes luks_passphrase optional).
 - --alpine-version: Specify Alpine Linux version (default: 3.20.3).
 - --root-enabled: Enable root access (default: disabled).
 - --root-password: Set the root password (ignored if root is disabled).
 - --user-password: Set the default user password.

### Example Usage

#### With Encryption:

```bash
./build.sh out/iso/alpine.iso 'my_luks_pass' --alpine-version 3.16 --root-enabled yes --root-password 'rootpass' --user-password 'userpass'
```

#### Without Encryption:
```bash
./build.sh out/iso/alpine.iso '' --no-luks --alpine-version 3.18
```


## Usage Instructions
### Build the ISO

The core ISO creation is handled by the script build.sh. For development, a Makefile is included to set up the environment and execute the script inside a Docker container.

#### Buld the ISO with encryption
Builds an encrypted ISO using LUKS with a default password of "123".
```
make build
```

#### Build the ISO without encryption
```
make no_luks
```

### Testing the ISO

After building the ISO, you can test it using QEMU:

#### UEFI Environment:
```
make uefi
```

#### BIOS Environment:
```
make bios
```

#### BIOS as CD-ROM:
```
make bios_cd
```
