package cmdVM

import (
	"encoding/json"
    "nexus-client/exec"
    "nexus-common/vm"
	"nexus-common/params"
	e "nexus-client/exec"
    u "nexus-client/utils"
    g "nexus-client/globals"
    "github.com/go-playground/validator/v10"
)

type AttachFromPwd struct {
    Name string
}

func (cmd *AttachFromPwd)GetName() string {
    return cmd.Name
}

func (cmd *AttachFromPwd)GetDesc() []string {
    return []string{
        "Attaches to the VM that matches the specified password.",
        "Requires the VM_ATTACH_ANY user capability."}
}

func (cmd *AttachFromPwd)PrintUsage() {
    for _, desc := range cmd.GetDesc() {
        u.PrintlnErr(desc)
    }
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("USAGE: ",cmd.GetName()," password")
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
}

func (cmd *AttachFromPwd)Run(args []string) int {
    if err := exec.CheckRemoteViewer(); err != nil {
        u.PrintlnErr(err.Error())
        return 1
    }

    argc := len(args)
    if argc != 1 {
        cmd.PrintUsage()
        return 1
    }

    client := g.GetInstance().Client
    host := g.GetInstance().Host

    hostname := g.GetInstance().Hostname
    cert := g.GetInstance().PubCert

	pwd := args[0]
    p := &params.VMAttachCreds{ Pwd: pwd }
    resp, err := client.R().SetBody(p).Post(host+"/vms/spicecreds")
    if err != nil {
        u.PrintlnErr("Failed retrieving VM credentials: "+err.Error())
        return 1
    }

    if resp.IsSuccess() {
        var creds vm.VMSpiceCredentialsSerialized
        if err := json.Unmarshal(resp.Body(), &creds); err != nil {
            u.PrintlnErr("Failed deserializing VM spice credentials: "+err.Error())
            return 1
        }
        if err := validator.New(validator.WithRequiredStructEnabled()).Struct(creds); err != nil {
            u.PrintlnErr("Failed validating VM spice credentials: "+err.Error())
            return 1
        }
        go func(creds vm.VMSpiceCredentialsSerialized) {
            _, err := e.RunRemoteViewer(hostname, cert, creds.Name, creds.SpicePort, creds.SpicePwd, true)
            if err != nil {
                u.PrintlnErr("Failed executing remote-viewer: "+err.Error())
            }
        } (creds)
    } else {
        type msg struct {
            Message string  `json:"message"`
        }
        var m msg
        if err := json.Unmarshal(resp.Body(), &m); err != nil {
			u.PrintlnErr("Failed retrieving VM credentials: "+err.Error())
			return 1
        }
		u.PrintlnErr("Failed retrieving VM credentials: "+m.Message)
		return 1
    }

    return 0
}
